#
# spec file
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2012 Togan Muftuoglu toganm@opensuse.org
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define flavor lua53%{nil}
%define mod_name luarocks
%define lua_value  %(echo "%{flavor}" |sed -e 's:lua::')
Version:        3.9.1
Release:        5.1
Summary:        A deployment and management system for Lua modules
License:        MIT
Group:          Development/Languages/Other
URL:            https://luarocks.org
Source0:        https://luarocks.org/releases/%{mod_name}-%{version}.tar.gz
Patch0:         lib64.patch
BuildRequires:  %{flavor}-devel
BuildRequires:  curl
BuildRequires:  lua-macros
BuildRequires:  openssl
BuildRequires:  unzip
Requires:       %{flavor}
Requires:       curl
Requires:       openssl
Requires:       unzip
Requires:       zip
Requires(post): update-alternatives
Requires(postun):update-alternatives
BuildArch:      noarch
%lua_provides
%if "%{flavor}" == ""
Name:           lua-%{mod_name}
ExclusiveArch:  do_not_build
%else
Name:           %{flavor}-%{mod_name}
%endif

%description
LuaRocks allows you to install Lua modules as self-contained packages
called "rocks", which also contain version dependency
information. This information is used both during installation, so
that when one rock is requested all rocks it depends on are installed
as well, and at run time, so that when a module is required, the
correct version is loaded. LuaRocks supports both local and remote
repositories, and multiple local rocks trees.

%prep
%autosetup -n %{mod_name}-%{version} -p1

%build
# Not an autotools based system
./configure \
  --prefix=%{_prefix} \
  --lua-version=%{lua_version}
make %{?_smp_mflags} build

%install
%make_install
mv %{buildroot}%{_bindir}/luarocks{,-%{lua_version}}
mv %{buildroot}%{_bindir}/luarocks-admin{,-%{lua_version}}

# update-alternatives
mkdir -p %{buildroot}%{_sysconfdir}/alternatives/
touch %{buildroot}%{_sysconfdir}/alternatives/luarocks
ln -sf %{_sysconfdir}/alternatives/luarocks %{buildroot}%{_bindir}/luarocks
touch %{buildroot}%{_sysconfdir}/alternatives/luarocks-admin
ln -sf %{_sysconfdir}/alternatives/luarocks %{buildroot}%{_bindir}/luarocks-admin

# rockstree
mkdir -p %{buildroot}%{luarocks_treedir}

%post
%{_sbindir}/update-alternatives --install %{_bindir}/luarocks luarocks %{_bindir}/luarocks-%{lua_version} %{lua_value} \
  --slave %{_bindir}/luarocks-admin luarocks-admin %{_bindir}/luarocks-admin-%{lua_version}

%postun
if [ "$1" = 0 ] ; then
	%{_sbindir}/update-alternatives --remove luarocks %{_bindir}/luarocks-%{lua_version}
fi

%files
%license COPYING
%doc README.md CHANGELOG.md
%dir %{_sysconfdir}/luarocks
%config(noreplace) %{_sysconfdir}/luarocks/config-%{lua_version}.lua
%ghost %{_sysconfdir}/alternatives/luarocks
%ghost %{_sysconfdir}/alternatives/luarocks-admin
%{_bindir}/luarocks
%{_bindir}/luarocks-admin
%{_bindir}/luarocks-%{lua_version}
%{_bindir}/luarocks-admin-%{lua_version}
%{lua_noarchdir}/luarocks
%dir %{_prefix}/lib/luarocks/rocks-%{lua_version}
%dir %{_prefix}/lib/luarocks

%changelog
* Thu Oct 26 2023 Marcos Bjoerkelund <marcos.bjoerkelund@suse.com>
- Fix luarocks-admin link, previously pointing to luarocks
* Wed Nov 23 2022 Michal Suchanek <msuchanek@suse.com>
- Fix missing dependency on lua-macros (boo#1205612)
* Fri Sep  2 2022 Callum Farmer <gmbr3@opensuse.org>
- Own /usr/lib/luarocks
* Fri Sep  2 2022 Callum Farmer <gmbr3@opensuse.org>
- Add lib64.patch:
  * Fix luarocks placing files in incorrect libdir
* Tue Aug 23 2022 Gordon Leung <pirateclip@protonmail.com>
- Add Requires: zip
  * Without it, luarocks fails when passed with arguments: make --pack-binary-rock
* Sun Aug 21 2022 Gordon Leung <pirateclip@protonmail.com>
- Update to version 3.9.1:
  * `builtin` build mode now always respects CC, CFLAGS and LDFLAGS
  * Check that lua.h version matches the desired Lua version
  * Check that the version of the Lua C library matches the desired Lua version
  * Fixed deployment of non-wrapped binaries
  * Fixed crash when `--lua-version` option is malformed
  * Fixed help message for `--pin` option
  * Unix: use native methods and don't always rely on $USER to determine user
* Sat Dec 18 2021 Callum Farmer <gmbr3@opensuse.org>
- Update to version 3.8.0:
  * Support GitHub's protocol security changes transparently
  * luarocks test has a new flag --prepare that checks, downloads
    and installs the tool requirements and rockspec dependencies
    but does not run the test suite for the rockspec being tested.
  * Code tweaks so that LuaRocks can run on a Lua interpreter
    built without the debug library.
* Tue Jun 15 2021 Callum Farmer <gmbr3@opensuse.org>
- Update to version 3.7.0
  * Improved connectivity resiliency
  * On Unix, it now respects environment variables $XDG_CACHE_HOME
    and $XDG_CONFIG_HOME
  * Fixes check for the default Lua version set in the user's
    home configuration
- Remove deprecated option --versioned-rocks-dir
* Thu Feb 18 2021 Callum Farmer <gmbr3@opensuse.org>
- Use %%lua_provides macro for default lua versioning
* Sun Jul 12 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update to version 3.3.1
  * Fix downgrades of rocks containing directories: stop it from creating spurious 0-byte files where directories have been
  * Fix error message when attempting to copy a file that is missing
  * For the changes made in 3.3.0 see https://github.com/luarocks/luarocks/blob/master/CHANGELOG.md#whats-new-in-luarocks-330
* Mon Jul  6 2020 Matej Cepl <mcepl@suse.com>
- Add lua54 as new build target
* Wed Aug 28 2019 Matej Cepl <mcepl@suse.com>
- Update to 3.2.0:
  * Bugfix: luarocks path does not change the order of
    pre-existing path items when prepending or appending to path
    variables
  * Bugfix: fix directory detection on the Mac
  * When building with --force-config, LuaRocks now never uses
    the "project" directory, but only the forced configuration
  * Lua libdir is now only checked for commands/platforms that
    really need to link Lua explicitly
  * LuaJIT is now detected dynamically
  * RaptorJIT is now detected as a LuaJIT variant
  * Improvements in Lua autodetection at runtime
  * luarocks new_version: new option --dir
  * luarocks which: report modules found via package.path and
    package.cpath as well
  * install.bat: Improved detection for Visual Studio 2017 and
    higher
* Sun May 26 2019 John Vandenberg <jayvdb@gmail.com>
- Re-enable building for Lua 5.3
- Add notable enhancements in changelog entry for v3.x update
- Update to v3.1.2
  * cmd: fix handling of unconfigured paths in get_lua_version
- from v3.1.1
  * fix: don't try to look in home_tree if not available
  * refactor: reorganise code in get_lua_version
  * fix: handle errors in lua wrapper check
- from v3.1.0
  * Includes many fixes and enhancements; full changelog is at
    https://github.com/luarocks/luarocks/compare/v3.0.4...v3.1.0
* Wed Oct 31 2018 mcepl@suse.com
- Upgrade to 3.0.4
  * Version 3.x is a large rewrite; full changelog is at
    https://github.com/luarocks/luarocks/blob/master/CHANGELOG.md
  * New rockspec format
  * New commands, including luarocks init for per-project workflows
  * New flags, including --lua-dir and --lua-version for using
    multiple Lua installs with a single LuaRocks
  * New build system
  * General improvements, including namespaces
  * User-visible changes, including some breaking changes
  * Internal changes
* Mon Oct 30 2017 jmatejek@suse.com
- do not build for Lua 5.2
* Fri Jul 14 2017 tchvatal@suse.com
- Switch to multibuild to produce luarocks for all lua variants
* Fri Jul 14 2017 tchvatal@suse.com
- Version update to 2.4.2:
  * New test suite based on Busted; runs on Linux, OSX and Windows
  * git+ssh:// fetch protocol
  * Improved behavior preserving permissions
  * Improved listing of dependencies on installation
  * Improved behavior of argument handling in `pack`
  * MSYS and Haiku platform detection
  * Feature-based detection of internal bit32 and utf8 modules
  * Internal reorganization of luarocks.fs code
  * `remove` option --force=fast renamed to --force-fast
  * Plus assorted bugfixes and cleanups
  * Avoid coroutine use in luarocks.loader
  * Fix upgrade issues for very old versions
  * Fixed conflict resolution on deploy/delete
  * Improved dependency check messages
  * Performance improvements when removing packages
  * Support user-defined `platforms` array in config file
  * Improvements in Lua interpreter version detection in Unix configure script
  * Relaxed Lua version detection to improve support for alternative implementations (e.g. Ravi)
  * Plus assorted bugfixes and improvements
* Mon Jul  4 2016 opensuse@mirell.de
- update to version 2.3.0
  * Windows: major redesign of the install tree structure
  * Windows: Auto setup of MSVC environments
  * Improve error messages when tools are not installed
  * CMake: generate 64-bit builds when appropriate
  * Improve check of location of config files
  * MacOSX: set MACOSX_DEPLOYMENT_TARGET using env
  * Remove --extensions flag; use rockspec_format instead
  * New `luarocks config` command to query configuration
  * Improved UI for messages when external deps are missing
  * Unix: Robustness improvement in configure script
  * Plus tweaks and bugfixes. See the changelog for details.
- Add correct library directory to configuration file to fix
  rocks that use C modules on x86_64 architecture
* Sat Jul 18 2015 i@marguerite.su
- update version 2.2.2
  * `luarocks build --only-deps` and `luarocks install --only-deps`
    for installing dependencies only
  * Mercurial support
  * Improved command-line argument parser, now validates arguments
    (it previously ignored unrecognized arguments) and accepts both
    `--flag=option` and `--flag option` in flags that take arguments.
  * For consistency with `luarocks show`, `luarocks doc --homepage`
    is now `luarocks doc --home`
  * Improvements to CMake build backend
  * Improved Makefiles for handling simultaneous bootstrapped
    installations
  * Various bugfixes
- changes in 2.2.1
  * Improved compatibility with Lua 5.3
  * `luarocks list --outdated` for listing modules with available
    upgrades
  * Assorted bugfixes
* Mon Oct 20 2014 i@marguerite.su
- update version 2.2.0
  * MoonRocks is the new default repository: http://rocks.moonscript.org
    Rocks don't need to be sent to the LuaRocks mailing list anymore,
    you can upload them directly at the website or using
  `luarocks upload` command for uploading rocks to MoonRocks via
    the command-line
  * Preliminary support for Lua 5.3
  * No longer uses the module() function, for Lua 5.2 installations
    built without Lua 5.1 compatibility
  * --branch flag for `luarocks build` and `luarocks make`
  * various improvements in `luarocks doc` command
  * "git+http" transport for source.url
* Mon Jan 21 2013 kianseong@gmail.com
- Updated version and made some changes
* Fri Sep 21 2012 toganm@opensuse.org
- Initial packaging
